==> therapi-runtime-javadoc-0.4.0-sources.jar: com/github/therapi/runtimejavadoc/MethodJavadoc.java <==
package com.github.therapi.runtimejavadoc;

import java.lang.reflect.Method;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

import static com.github.therapi.runtimejavadoc.internal.RuntimeJavadocHelper.unmodifiableDefensiveCopy;

public class MethodJavadoc {
    private final String name;
    private final List<String> paramTypes;
    private final Comment comment;
    private final List<ParamJavadoc> params;
    private final List<ThrowsJavadoc> exceptions;
    private final List<OtherJavadoc> other;
    private final Comment returns;
    private final List<SeeAlsoJavadoc> seeAlso;

    public MethodJavadoc(String name,
                         List<String> paramTypes,
                         Comment comment,
                         List<ParamJavadoc> params,
                         List<ThrowsJavadoc> exceptions,
                         List<OtherJavadoc> other,
                         Comment returns,
                         List<SeeAlsoJavadoc> seeAlso) {
        this.name = name;
        this.paramTypes = paramTypes;
        this.comment = comment;
        this.params = unmodifiableDefensiveCopy(params);
        this.exceptions = unmodifiableDefensiveCopy(exceptions);
        this.other = unmodifiableDefensiveCopy(other);
        this.returns = returns;
        this.seeAlso = unmodifiableDefensiveCopy(seeAlso);
    }

    public boolean matches(Method method) {
        if (!method.getName().equals(name)) {
            return false;
        }
        List<String> methodParamsTypes = Arrays.stream(method.getParameterTypes())
                                               .map(Class::getCanonicalName)
                                               .collect(Collectors.toList());
        return methodParamsTypes.equals(paramTypes);
    }

    public String getName() {
        return name;
    }

    public List<String> getParamTypes() {
        return paramTypes;
    }

    public Comment getComment() {
        return comment;
    }

    public List<ParamJavadoc> getParams() {
        return params;
    }

    public List<ThrowsJavadoc> getThrows() {
        return exceptions;
    }

    public List<OtherJavadoc> getOther() {
        return other;
    }

    public Comment getReturns() {
        return returns;
    }

    public List<SeeAlsoJavadoc> getSeeAlso() {
        return seeAlso;
    }

    @Override
    public String toString() {
        return "MethodJavadoc{" +
                "name='" + name + '\'' +
                ", paramTypes='" + paramTypes + '\'' +
                ", comment=" + comment +
                ", params=" + params +
                ", exceptions=" + exceptions +
                ", other=" + other +
                ", returns=" + returns +
                ", seeAlso=" + seeAlso +
                '}';
    }
}

==> therapi-runtime-javadoc-0.7.0-sources.jar: com/github/therapi/runtimejavadoc/MethodJavadoc.java <==
package com.github.therapi.runtimejavadoc;

import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.List;

import static com.github.therapi.runtimejavadoc.internal.RuntimeJavadocHelper.unmodifiableDefensiveCopy;

public class MethodJavadoc extends BaseJavadoc {
    private final List<String> paramTypes;
    private final List<ParamJavadoc> params;
    private final List<ThrowsJavadoc> exceptions;
    private final Comment returns;

    public MethodJavadoc(String name,
                         List<String> paramTypes,
                         Comment comment,
                         List<ParamJavadoc> params,
                         List<ThrowsJavadoc> exceptions,
                         List<OtherJavadoc> other,
                         Comment returns,
                         List<SeeAlsoJavadoc> seeAlso) {
        super(name, comment, seeAlso, other);
        this.paramTypes = unmodifiableDefensiveCopy(paramTypes);
        this.params = unmodifiableDefensiveCopy(params);
        this.exceptions = unmodifiableDefensiveCopy(exceptions);
        this.returns = Comment.nullToEmpty(returns);
    }

    public static MethodJavadoc createAbsent(Method method) {
        return new MethodJavadoc(method.getName(), null, null, null, null, null, null, null) {
            @Override
            public boolean isPresent() {
                return false;
            }
        };
    }

    public boolean matches(Method method) {
        if (!method.getName().equals(getName())) {
            return false;
        }
        List<String> methodParamsTypes = new ArrayList<>();
        for (Class<?> aClass : method.getParameterTypes()) {
            methodParamsTypes.add(aClass.getCanonicalName());
        }
        return methodParamsTypes.equals(paramTypes);
    }

    public List<String> getParamTypes() {
        return paramTypes;
    }

    public List<ParamJavadoc> getParams() {
        return params;
    }

    public List<ThrowsJavadoc> getThrows() {
        return exceptions;
    }

    public Comment getReturns() {
        return returns;
    }

    @Override
    public String toString() {
        return "MethodJavadoc{" +
                "name='" + getName() + '\'' +
                ", paramTypes='" + paramTypes + '\'' +
                ", comment=" + getComment() +
                ", params=" + params +
                ", exceptions=" + exceptions +
                ", other=" + getOther() +
                ", returns=" + returns +
                ", seeAlso=" + getSeeAlso() +
                '}';
    }
}
